// Copyright (c) 2013 by István Váradi

// This file is part of XPLRA, a remote-access plugin for X-Plane

// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:

// 1. Redistributions of source code must retain the above copyright notice, this
//    list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright notice,
//    this list of conditions and the following disclaimer in the documentation
//    and/or other materials provided with the distribution.

// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
// ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
// (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
// LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
// ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

// The views and conclusions contained in the software and documentation are those
// of the authors and should not be interpreted as representing official policies,
// either expressed or implied, of the FreeBSD Project.

#ifndef XPLRA_GLOBALS_H
#define XPLRA_GLOBALS_H
//------------------------------------------------------------------------------

#include "MessageWindow.h"
#include "Menu.h"

//------------------------------------------------------------------------------

namespace xplra {

//------------------------------------------------------------------------------

/**
 * Class containing the globals for the enabled instance of the
 * plugin.
 */
class Globals
{
private:
    /**
     * The version of X-Plane.
     */
    int xplaneVersion;

    /**
     * The version of the XPLM library.
     */
    int xplmVersion;

    /**
     * The message window.
     */
    MessageWindow messageWindow;

    /**
     * The menu.
     */
    Menu menu;

public:
    /**
     * Construct the globals.
     */
    Globals();

    /**
     * Get the versions.
     */
    void getVersions(int& xplaneV, int& xplmV) const;

    /**
     * Get the message window.
     */
    MessageWindow& getMessageWindow();
};

//------------------------------------------------------------------------------
// Inline definitions
//------------------------------------------------------------------------------

inline MessageWindow& Globals::getMessageWindow()
{
    return messageWindow;
}

//------------------------------------------------------------------------------

inline void Globals::getVersions(int& xplaneV, int& xplmV) const
{
    xplaneV = xplaneVersion;
    xplmV = xplmVersion;
}

//------------------------------------------------------------------------------

} /* namespace xplra */

//------------------------------------------------------------------------------
#endif // XPLRA_GLOBALS_H

// Local Variables:
// mode: C++
// c-basic-offset: 4
// indent-tabs-mode: nil
// End:
