// Copyright (c) 2013 by István Váradi

// This file is part of XPLRA, a remote-access plugin for X-Plane

// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:

// 1. Redistributions of source code must retain the above copyright notice, this
//    list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright notice,
//    this list of conditions and the following disclaimer in the documentation
//    and/or other materials provided with the distribution.

// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
// ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
// (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
// LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
// ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

// The views and conclusions contained in the software and documentation are those
// of the authors and should not be interpreted as representing official policies,
// either expressed or implied, of the FreeBSD Project.

//------------------------------------------------------------------------------

#include "Menu.h"

#include "MessageWindow.h"

//------------------------------------------------------------------------------

using xplra::Menu;

//------------------------------------------------------------------------------

void Menu::menuHandlerCallback(void* menuRef, void* itemRef)
{
    Menu* menu = reinterpret_cast<Menu*>(menuRef);
    menu->handleMenu(itemRef);
}

//------------------------------------------------------------------------------

Menu::Menu(MessageWindow& messageWindow) :
    messageWindow(messageWindow),
    menuID(0),
    showMessageAreaIndex(-1)
{
    XPLMMenuID pluginsMenuID = XPLMFindPluginsMenu();

    int menuIndex = XPLMAppendMenuItem(pluginsMenuID, "Remote Access", 0, 1);
    menuID = XPLMCreateMenu("Remote Access", pluginsMenuID, menuIndex,
                            &menuHandlerCallback, this);
    showMessageAreaIndex = XPLMAppendMenuItem(menuID, "Show message area",
                                              0, 1);
    XPLMCheckMenuItem(menuID, showMessageAreaIndex, xplm_Menu_Unchecked);
}

//------------------------------------------------------------------------------

void Menu::handleMenu(void* /*itemRef*/)
{
    XPLMMenuCheck checked = xplm_Menu_NoCheck;
    XPLMCheckMenuItemState(menuID, showMessageAreaIndex, &checked);
    if (checked==xplm_Menu_Unchecked) {
        XPLMCheckMenuItem(menuID, showMessageAreaIndex, xplm_Menu_Checked);
        messageWindow.show();
    } else if (checked==xplm_Menu_Checked) {
        XPLMCheckMenuItem(menuID, showMessageAreaIndex, xplm_Menu_Unchecked);
        messageWindow.hide();
    }
}

//------------------------------------------------------------------------------

// Local Variables:
// mode: C++
// c-basic-offset: 4
// indent-tabs-mode: nil
// End:
